from ypricemagic.price_modules import (aave, belt, compound, cream, ellipsis,
                                       froyo, gelato, ib, mooniswap,
                                       mstablefeederpool, piedao, tokensets,
                                       wsteth, yearn)

__all__ = [
    'aave',
    'belt',
    'compound',
    'cream',
    'ellipsis',
    'froyo',
    'gelato',
    'ib',
    'mooniswap',
    'mstablefeederpool',
    'piedao',
    'tokensets',
    'wsteth',
    'yearn',
]